package com.ruoyi.yh.report.service.impl;

import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.service.ISysDeptService;
import com.ruoyi.system.service.ISysUserService;
import com.ruoyi.yh.price.domain.PriceQuery;
import com.ruoyi.yh.price.service.PriceService;
import com.ruoyi.yh.report.domain.Report;
import com.ruoyi.yh.report.domain.ReportVO;
import com.ruoyi.yh.report.domain.bo.ReportBO;
import com.ruoyi.yh.report.domain.enums.ReportStatus;
import com.ruoyi.yh.report.service.ReportConverter;
import com.ruoyi.yh.reportProd.domain.ReportProd;
import com.ruoyi.yh.reportProd.domain.ReportProdVO;
import com.ruoyi.yh.reportProd.domain.bo.ReportProdBO;
import com.ruoyi.yh.reportProd.service.ReportProdConverter;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * @author wjh
 * 2024/10/31
 */
@Service
public class ReportConverterImpl implements ReportConverter {

    @Autowired
    private ISysUserService userService;

    @Autowired
    private PriceService priceService;

    @Autowired
    private ReportProdConverter reportProdConverter;

    @Autowired
    private ISysDeptService deptService;

    @Override
    public ReportBO toBoByCreate(ReportVO vo) {
        if (vo == null) {
            return null;
        }

        LoginUser loginUser = SecurityUtils.getLoginUser();

        // 报表主表数据
        ReportBO bo = new ReportBO();
        bo.setDeptId(vo.getDeptId());
        bo.setStatus(ReportStatus.WAIT_VERIFY.getStatus());
        bo.setCreateId(loginUser.getUserId());
        bo.setReportDate(vo.getReportDate());
        bo.setTotalAmount(vo.getTotalAmount());
        bo.setCreateBy(loginUser.getUsername());

        // 报表产量数据
        List<ReportProdBO> productList = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(vo.getProductList())) {
            for (ReportProdVO item : vo.getProductList()) {
                ReportProdBO prodBo = reportProdConverter.toBoByCreate(item);
                productList.add(prodBo);
            }
        }

        // 组装数据
        bo.setProductList(productList);
        bo.setDept(deptService.selectDeptById(bo.getDeptId(), true));
        return bo;
    }

    @Override
    public ReportBO toBoByUpdate(ReportVO vo) {
        if (vo == null) {
            return null;
        }

        LoginUser loginUser = SecurityUtils.getLoginUser();

        // 报表主表数据
        ReportBO bo = new ReportBO();
        bo.setReportId(vo.getReportId());
        bo.setDeptId(vo.getDeptId());
        bo.setReportDate(vo.getReportDate());
        bo.setTotalAmount(vo.getTotalAmount());
        bo.setStatus(ReportStatus.WAIT_VERIFY.getStatus());
        bo.setUpdateId(loginUser.getUserId());
        bo.setUpdateBy(loginUser.getUsername());

        // 报表产量数据
        List<ReportProdBO> productList = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(vo.getProductList())) {
            for (ReportProdVO item : vo.getProductList()) {
                ReportProdBO prodBo = reportProdConverter.toBoByUpdate(item);
                productList.add(prodBo);
            }
        }

        // 组装数据
        bo.setProductList(productList);
        bo.setDept(deptService.selectDeptById(bo.getDeptId(), true));
        return bo;
    }
}
